#!/usr/bin/env python

import numpy as np
import scipy.misc

import utils

img = scipy.misc.lena().astype(np.float)

print 'Saving original image to pngs/orig.png'
utils.write_png('orig', img)

print 'Computing SVD for image'
U, d, D, Vt = utils.svd(img)

print 'Computing DCT for img.'
dct = utils.dct(img)

separator = utils.generate_sep(len(img))

svd_scale = []
svd_graph = []

dct_scale = []
dct_graph = []

for k in range(5, 130, 25):
    print 'Computing rank approximation for ' + str(k)
    approx = utils.rank_approx(U, d, D, Vt, k)

    name = 'svd_approx_' + str(k)

    utils.append_to_scale(svd_scale, approx)

    svd_graph.append(dict(name=name, k=k))

    print 'Saved rank approximation to ' + name
    utils.write_png(name, approx)

for k in range(25, 250, 50):
    print 'Computing DCT approximation for ' + str(k)
    approx = utils.dct_approx(dct, k)

    name = 'dct_approx_' + str(k)

    utils.append_to_scale(dct_scale, approx)

    dct_graph.append(dict(name=name, k=k))

    print 'Saved DCT approximation to ' + name
    utils.write_png(name, approx)

utils.append_to_scale(svd_scale, img)
print 'Saved scale for rank approximation to svd_scale.png'
utils.write_png('svd_scale', scale=svd_scale)

utils.write_graph(svd_graph, 'SVD', 'svd_graph')

utils.append_to_scale(dct_scale, img)
print 'Saved scale for DCT approximation to dct_scale.png'
utils.write_png('dct_scale', scale=dct_scale)

utils.write_graph(dct_graph, 'DCT', 'dct_graph')

utils.write_comp_graph(svd_graph, dct_graph)
